# verrific
Python package for cross-checking and verifying references in scientific papers, designed for use with scienceverse/papercheck 

NOT WORKING YET!

[![PyPI - Downloads](https://img.shields.io/pypi/dm/verrific.svg)](https://pypi.org/project/verrific)
[![PyPI - License](https://img.shields.io/pypi/l/verrific.svg)](https://pypi.org/project/verrific)
[![GitHub - Stars](https://img.shields.io/github/stars/thesanogoeffect/verrific.svg?style=social)](
[![PyPI - Version](https://img.shields.io/pypi/v/verrific.svg)](https://pypi.org/project/verrific)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/verrific.svg)](https://pypi.org/project/verrific)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install verrific
```

## License

`verrific` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.